@@ -42,6 +42,10 @@ class EncoderMotor(Stateful, Recreatable):
     :type wheel_diameter: int or float
     :param wheel_diameter:
         The diameter of the wheel attached to the motor.
+
+    :type name: str
+    :param name:
+        Component name, defaults to `encoder_motor`. Used to access this component when added to a :class:`pitop.Pitop` object.
     """
 
     MMK_STANDARD_GEAR_RATIO = 41.8
@@ -53,12 +57,15 @@ class EncoderMotor(Stateful, Recreatable):
         forward_direction,
         braking_type=BrakingType.BRAKE,
         wheel_diameter=0.075,
-        name=None,
+        name="encoder_motor",
     ):
         self.name = name
         self._pma_port = port_name
 
-        self.__motor_core = EncoderMotorController(self._pma_port, braking_type.value)
+        if isinstance(braking_type, BrakingType):
+            braking_type = braking_type.value
+
+        self.__motor_core = EncoderMotorController(self._pma_port, braking_type)
         self.__forward_direction = forward_direction
         self.__wheel_diameter = wheel_diameter
 
@@ -94,12 +101,13 @@ class EncoderMotor(Stateful, Recreatable):
     def forward_direction(self):
         """Represents the forward direction setting used by the motor.
 
-        Setting this property will determine on which direction the motor will turn
-        whenever a movement in a particular direction is requested.
+        Setting this property will determine on which direction the
+        motor will turn whenever a movement in a particular direction is
+        requested.
 
         :type forward_direction: ForwardDirection
-        :param forward_direction:
-            The direction that corresponds to forward motion.
+        :param forward_direction: The direction that corresponds to
+            forward motion.
         """
         return ForwardDirection(self.__forward_direction)
 
@@ -125,7 +133,6 @@ class EncoderMotor(Stateful, Recreatable):
 
     @braking_type.setter
     def braking_type(self, braking_type):
-
         self.__motor_core.set_braking_type(braking_type.value)
 
     def set_power(self, power, direction=Direction.FORWARD):
